==> infima_client-0.39.0-py3-none-any.whl: infima_client/models/latest_pool_predictions.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_prediction import PoolPrediction
from ..types import UNSET, Unset

T = TypeVar("T", bound="LatestPoolPredictions")


@attr.s(auto_attribs=True)
class LatestPoolPredictions:
    """  """

    predictions: Union[Unset, List[PoolPrediction]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        predictions: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.predictions, Unset):
            predictions = []
            for predictions_item_data in self.predictions:
                predictions_item = predictions_item_data.to_dict()

                predictions.append(predictions_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if predictions is not UNSET:
            field_dict["predictions"] = predictions

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        predictions = []
        _predictions = d.pop("predictions", UNSET)
        for predictions_item_data in _predictions or []:
            predictions_item = PoolPrediction.from_dict(predictions_item_data)

            predictions.append(predictions_item)

        latest_pool_predictions = cls(
            predictions=predictions,
        )

        latest_pool_predictions.additional_properties = d
        return latest_pool_predictions

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/latest_pool_predictions.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.prediction_service_get_latest_pools_response_200_predictions_item import (
    PredictionService_GetLatestPoolsResponse_200PredictionsItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="LatestPoolPredictions")


@attr.s(auto_attribs=True)
class LatestPoolPredictions:
    """  """

    predictions: Union[
        Unset, List[PredictionService_GetLatestPoolsResponse_200PredictionsItem]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        predictions: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.predictions, Unset):
            predictions = []
            for predictions_item_data in self.predictions:
                predictions_item = predictions_item_data.to_dict()

                predictions.append(predictions_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if predictions is not UNSET:
            field_dict["predictions"] = predictions

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        predictions = []
        _predictions = d.pop("predictions", UNSET)
        for predictions_item_data in _predictions or []:
            predictions_item = (
                PredictionService_GetLatestPoolsResponse_200PredictionsItem.from_dict(
                    predictions_item_data
                )
            )

            predictions.append(predictions_item)

        latest_pool_predictions = cls(
            predictions=predictions,
        )

        latest_pool_predictions.additional_properties = d
        return latest_pool_predictions

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
